DataProcessorManager
=================================

.. autoclass:: sdgx.data_processors.manager.DataProcessorManager
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
   :private-members:
